@@ -38,19 +38,31 @@ pub fn format_receiver_args_macro(input: proc_macro::TokenStream) -> proc_macro:
             FormatPartType::StaticAscii(ascii_string) => {
                 let str_as_bytes = byte_str_literal(ascii_string.as_bytes());
                 quote! (
-                    elrond_wasm::formatter::FormatReceiver::push_static_ascii(&mut $accumulator_expr, $str_as_bytes);
+                    elrond_wasm::formatter::FormatBuffer::append_ascii(&mut $accumulator_expr, $str_as_bytes);
                 )
             },
-            FormatPartType::Ascii => {
+            FormatPartType::Display => {
                 let arg_expr = tokens_iter.next().unwrap();
                 quote! (
-                    elrond_wasm::formatter::FormatReceiver::push_top_encode_bytes(&mut $accumulator_expr, &$arg_expr);
+                    elrond_wasm::formatter::FormatBuffer::append_display(&mut $accumulator_expr, &$arg_expr);
                 )
             },
-            FormatPartType::Hex => {
+            FormatPartType::LowerHex => {
                 let arg_expr = tokens_iter.next().unwrap();
                 quote! (
-                    elrond_wasm::formatter::FormatReceiver::push_top_encode_hex(&mut $accumulator_expr, &$arg_expr);
+                    elrond_wasm::formatter::FormatBuffer::append_lower_hex(&mut $accumulator_expr, &$arg_expr);
+                )
+            },
+            FormatPartType::Codec => {
+                let arg_expr = tokens_iter.next().unwrap();
+                quote! (
+                    elrond_wasm::formatter::FormatBuffer::append_codec(&mut $accumulator_expr, &$arg_expr);
+                )
+            },
+            FormatPartType::Bytes => {
+                let arg_expr = tokens_iter.next().unwrap();
+                quote! (
+                    elrond_wasm::formatter::FormatBuffer::append_binary(&mut $accumulator_expr, &$arg_expr);
                 )
             },
         }
