@@ -74,7 +74,6 @@ fn process_arg_attribute(attr: &syn::Attribute, arg_metadata: &mut ArgMetadata)
         || process_payment_nonce_attribute(attr, arg_metadata)
         || process_payment_amount_attribute(attr, arg_metadata)
         || process_payment_multi_attribute(attr, arg_metadata)
-        || process_var_args_attribute(attr, arg_metadata)
         || process_callback_result_attribute(attr, arg_metadata)
         || process_event_topic_attribute(attr, arg_metadata)
 }
@@ -119,14 +118,6 @@ fn process_payment_multi_attribute(attr: &syn::Attribute, arg_metadata: &mut Arg
     has_attr
 }
 
-fn process_var_args_attribute(attr: &syn::Attribute, arg_metadata: &mut ArgMetadata) -> bool {
-    let has_attr = is_var_args(attr);
-    if has_attr {
-        arg_metadata.var_args = true;
-    }
-    has_attr
-}
-
 fn process_callback_result_attribute(
     attr: &syn::Attribute,
     arg_metadata: &mut ArgMetadata,
